==> zio-aws-elasticsearch_2.12-5.17.104.12-sources.jar: zio/aws/elasticsearch/model/CreateElasticsearchDomainResponse.scala <==
package zio.aws.elasticsearch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateElasticsearchDomainResponse(
    domainStatus: Option[
      zio.aws.elasticsearch.model.ElasticsearchDomainStatus
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.CreateElasticsearchDomainResponse = {
    import CreateElasticsearchDomainResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.CreateElasticsearchDomainResponse
      .builder()
      .optionallyWith(domainStatus.map(value => value.buildAwsValue()))(
        _.domainStatus
      )
      .build()
  }
  def asReadOnly
      : zio.aws.elasticsearch.model.CreateElasticsearchDomainResponse.ReadOnly =
    zio.aws.elasticsearch.model.CreateElasticsearchDomainResponse
      .wrap(buildAwsValue())
}
object CreateElasticsearchDomainResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.CreateElasticsearchDomainResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticsearch.model.CreateElasticsearchDomainResponse =
      zio.aws.elasticsearch.model.CreateElasticsearchDomainResponse(
        domainStatus.map(value => value.asEditable)
      )
    def domainStatus
        : Option[zio.aws.elasticsearch.model.ElasticsearchDomainStatus.ReadOnly]
    def getDomainStatus: ZIO[
      Any,
      AwsError,
      zio.aws.elasticsearch.model.ElasticsearchDomainStatus.ReadOnly
    ] = AwsError.unwrapOptionField("domainStatus", domainStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.CreateElasticsearchDomainResponse
  ) extends zio.aws.elasticsearch.model.CreateElasticsearchDomainResponse.ReadOnly {
    override val domainStatus: Option[
      zio.aws.elasticsearch.model.ElasticsearchDomainStatus.ReadOnly
    ] = scala
      .Option(impl.domainStatus())
      .map(value =>
        zio.aws.elasticsearch.model.ElasticsearchDomainStatus.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.CreateElasticsearchDomainResponse
  ): zio.aws.elasticsearch.model.CreateElasticsearchDomainResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elasticsearch_2.13-5.17.224.2-sources.jar: zio/aws/elasticsearch/model/CreateElasticsearchDomainResponse.scala <==
package zio.aws.elasticsearch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateElasticsearchDomainResponse(
    domainStatus: Optional[
      zio.aws.elasticsearch.model.ElasticsearchDomainStatus
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.CreateElasticsearchDomainResponse = {
    import CreateElasticsearchDomainResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.CreateElasticsearchDomainResponse
      .builder()
      .optionallyWith(domainStatus.map(value => value.buildAwsValue()))(
        _.domainStatus
      )
      .build()
  }
  def asReadOnly
      : zio.aws.elasticsearch.model.CreateElasticsearchDomainResponse.ReadOnly =
    zio.aws.elasticsearch.model.CreateElasticsearchDomainResponse
      .wrap(buildAwsValue())
}
object CreateElasticsearchDomainResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.CreateElasticsearchDomainResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticsearch.model.CreateElasticsearchDomainResponse =
      zio.aws.elasticsearch.model.CreateElasticsearchDomainResponse(
        domainStatus.map(value => value.asEditable)
      )
    def domainStatus: Optional[
      zio.aws.elasticsearch.model.ElasticsearchDomainStatus.ReadOnly
    ]
    def getDomainStatus: ZIO[
      Any,
      AwsError,
      zio.aws.elasticsearch.model.ElasticsearchDomainStatus.ReadOnly
    ] = AwsError.unwrapOptionField("domainStatus", domainStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.CreateElasticsearchDomainResponse
  ) extends zio.aws.elasticsearch.model.CreateElasticsearchDomainResponse.ReadOnly {
    override val domainStatus: Optional[
      zio.aws.elasticsearch.model.ElasticsearchDomainStatus.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.domainStatus())
      .map(value =>
        zio.aws.elasticsearch.model.ElasticsearchDomainStatus.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.CreateElasticsearchDomainResponse
  ): zio.aws.elasticsearch.model.CreateElasticsearchDomainResponse.ReadOnly =
    new Wrapper(impl)
}
